function outtext = ReadText(file)
% ReadText: Reads the contents of a text file.
%
% USAGE:
%
%       outtext = ReadText(file)
%
% REQUIRED INPUTS: file (string) with full path+name+extension of file (e.g. c:\code\myfile.txt)
%                       Any type of file, including binary files, can be checked by the function.
%
% REQUIRED OUTPUT: outtext (cell string) with as many elements as there are rows in file. If the file
%                       is either a binary file, does not exist, or is empty, then ReadText returns
%                       and empty string.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/EMO
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2008 European Central Bank.
%
%                       First version: July 18, 2006.
%                        This version: December 8, 2008.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 19-7-2006:  Updated function information.
%
% * 13-11-2007: Updated the documentation.
%
% * 23-5-2008:  Updated the documentation.
%
% * 8-12-2008:  Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
outtext = '';
fid = fopen(file,'rt');
if fid>-1;
   fileline = fgetl(fid);
   num = 1;
   out = '';
   while isnumeric(fileline)==0;
      if strcmp(fileline,'')==0;
         if strcmp(out,'')==1;
            out = 'alina';
         end;
         outtext{num} = fileline;
         num = num+1;
      else;
         outtext{num} = '';
         num = num+1;
      end;
      fileline = fgetl(fid);
   end;
   fclose(fid);
end;

%
% end of ReadText.m
%
